import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import Button from './Button';


const TestButton = Button({
    block: purebem.of('test-button'),
    displayName: 'TestButton',
    Spinner: () => (<div />)
});

describe('Button', () => {

    it('should trigger click event when clicked', () => {
        const onClick = jest.fn();

        const button = TestUtils.renderIntoDocument(
            <TestButton
                onClick={ onClick } />
        );

        const node = ReactDOM.findDOMNode(button);
        TestUtils.Simulate.click(node);

        expect(onClick).toHaveBeenCalled();
    });

    it('should not trigger click event when clicked and disabled', () => {
        const onClick = jest.fn();

        const button = TestUtils.renderIntoDocument(
            <TestButton
                disabled={ true }
                onClick={ onClick } />
        );

        const node = ReactDOM.findDOMNode(button);
        TestUtils.Simulate.click(node);

        expect(onClick).not.toHaveBeenCalled();
    });

});
