import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import LinkButton from './LinkButton';

import AnchorTestWrapper from '../../test-utils/AnchorTestWrapper';


const TestLinkButton = LinkButton({
    block: purebem.of('test-button'),
    displayName: 'TestLinkButton'
});

describe('LinkButton', () => {

    it('should navigate', () => {
        const wrapper = TestUtils.renderIntoDocument(
            <AnchorTestWrapper>
                <TestLinkButton />
            </AnchorTestWrapper>
        );

        const button = TestUtils.findRenderedComponentWithType(wrapper, TestLinkButton);
        const node = ReactDOM.findDOMNode(button);

        TestUtils.Simulate.click(node);

        expect(wrapper.didNavigate).toBeTruthy();
    });

    it('should trigger click event when clicked', () => {
        const onClick = jest.fn();

        const button = TestUtils.renderIntoDocument(
            <TestLinkButton
                onClick={ onClick } />
        );

        const node = ReactDOM.findDOMNode(button);

        TestUtils.Simulate.click(node);

        expect(onClick).toHaveBeenCalled();
    });

    it('should not trigger click event nor navigate when clicked and disabled', () => {
        const onClick = jest.fn();

        const wrapper = TestUtils.renderIntoDocument(
            <AnchorTestWrapper>
                <TestLinkButton
                    disabled={ true }
                    onClick={ onClick } />
            </AnchorTestWrapper>
        );

        const button = TestUtils.findRenderedComponentWithType(wrapper, TestLinkButton);
        const node = ReactDOM.findDOMNode(button);

        TestUtils.Simulate.click(node);

        expect(onClick).not.toHaveBeenCalled();
        expect(wrapper.didNavigate).toBeFalsy();
    });

});
