import reduceReducers from 'reduce-reducers';
import Immutable from 'seamless-immutable';

import { reducer as mount } from './mount';
import { reducer as unmount } from './unmount';

import { reducer as checkboxChange } from '../../checkbox/redux/checkboxChange';

import { reducer as dropdownChange } from '../../dropdown/redux/dropdownChange';
import { reducer as dropdownCollapse } from '../../dropdown/redux/dropdownCollapse';
import { reducer as dropdownExpand } from '../../dropdown/redux/dropdownExpand';
import { reducer as dropdownHighlightedIndexChange } from '../../dropdown/redux/dropdownHighlightedIndexChange';

import { reducer as radioButtonGroupChange } from '../../radio/redux/radioButtonGroupChange';

import { reducer as textareaChange } from '../../textarea/redux/textareaChange';
import { reducer as textboxChange } from '../../textbox/redux/textboxChange';

import convertActionObjectToHandlers from '../../../utils/convertActionObjectToHandlers';


export default ({
    actionObject = {},
    defaultState = {},
    reducers = []
} = {}) => {
    const meta = defaultState.meta;
    // alas, seamless-immutable doesn't support using Set.
    const initialState = { ...defaultState, meta: { ...meta, mounted: {} } };

    return {
        components: (state = Immutable(initialState), action) => {
            return reduceReducers(
                checkboxChange,

                dropdownChange,
                dropdownCollapse,
                dropdownExpand,
                dropdownHighlightedIndexChange,

                radioButtonGroupChange,

                textareaChange,

                textboxChange,

                ...convertActionObjectToHandlers({
                    ...mount,
                    ...unmount
                }),

                ...convertActionObjectToHandlers(actionObject),
                ...reducers
            )(state, action);
        }
    };
};
