import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import RadioButtonGroup from './RadioButtonGroup';
import RadioButtonGroupContainer, { changeType } from './RadioButtonGroupContainer';

import radioButtonGroupChange from './redux/radioButtonGroupChange';
import radioButtonGroupState from './redux/radioButtonGroupState';
import radioButtonOptionState from './redux/radioButtonOptionState';

import createStore from '../../test-utils/createStore';


const block = purebem.of('test-radio-button-group');

const radioButtonOptionElement = block('option');

const TestRadioButtonGroup = RadioButtonGroup({
    block,
    displayName: 'TestRadioButtonGroup'
});

const TestRadioButtonGroupContainer = RadioButtonGroupContainer({
    Component: TestRadioButtonGroup
});

describe('RadioButtonGroupContainer', () => {
    const path = 'condition';
    const root = 'test';
    const actionTypePrefix = 'TEST-RADIO-BUTTON-GROUP';

    it('should dispatch change event on change', () => {
        const store = createStore({
            test: {
                condition: radioButtonGroupState({
                    options: [
                        radioButtonOptionState({
                            value: 'a'
                        }),
                        radioButtonOptionState({
                            value: 'b'
                        })
                    ],
                    value: 'a'
                })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestRadioButtonGroupContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const options = TestUtils.scryRenderedDOMComponentsWithClass(provider, radioButtonOptionElement);
        expect(options.length).toBe(2);

        TestUtils.Simulate.click(ReactDOM.findDOMNode(options[1]));

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(radioButtonGroupChange({
            path,
            root,
            type: changeType(actionTypePrefix),
            value: 'b'
        }));
    });

});
