import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import RadioButtonOption from './RadioButtonOption';


const TestRadioButtonOption = RadioButtonOption({
    block: purebem.of('test-radio-button-group'),
    displayName: 'TestRadioButtonOption'
});

describe('RadioButtonOption', () => {

    it('should change value when clicked and is unchecked', () => {
        const onChange = jest.fn();

        const option = TestUtils.renderIntoDocument(
            <TestRadioButtonOption
                checked={ false }
                onChange={ onChange }
                value="test" />
        );

        const node = ReactDOM.findDOMNode(option);
        TestUtils.Simulate.click(node);

        expect(onChange).toHaveBeenCalledWith('test');
    });

    [
        { name: 'should not change value when clicked and is unchecked and disabled', data: { checked: false } },
        { name: 'should not change value when clicked and is checked and disabled', data: { checked: true } }
    ].forEach((fixture) => {
        it(fixture.name, () => {
            const onChange = jest.fn();

            const option = TestUtils.renderIntoDocument(
                <TestRadioButtonOption
                    checked={ fixture.data.checked }
                    disabled={ true }
                    onChange={ onChange }
                    value="test" />
            );

            const node = ReactDOM.findDOMNode(option);
            TestUtils.Simulate.click(node);

            expect(onChange).not.toHaveBeenCalled();
        });
    });

});
